==> dfu-1.8.0-sources.jar: no/nordicsemi/android/dfu/DfuLogListener.java <==
/*
 * Copyright (c) 2018, Nordic Semiconductor
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package no.nordicsemi.android.dfu;

/**
 * Listener for log events. This listener should be used instead of creating the BroadcastReceiver on your own.
 * @see DfuServiceListenerHelper
 */
public interface DfuLogListener {
	/**
	 * Method called when a log event was sent from the DFU service.
	 * @param deviceAddress the target device address
	 * @param level the log level, one of:
	 * 		<ul>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_DEBUG}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_VERBOSE}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_INFO}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_APPLICATION}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_WARNING}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_ERROR}</li>
	 * 		</ul>
	 * @param message the log message
	 */
	void onLogEvent(final String deviceAddress, final int level, final String message);
}

==> dfu-1.9.1-sources.jar: no/nordicsemi/android/dfu/DfuLogListener.java <==
/*
 * Copyright (c) 2018, Nordic Semiconductor
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package no.nordicsemi.android.dfu;

/**
 * Listener for log events. This listener should be used instead of creating the
 * BroadcastReceiver on your own.
 *
 * @see DfuServiceListenerHelper
 */
public interface DfuLogListener {
	/**
	 * Method called when a log event was sent from the DFU service.
	 *
	 * @param deviceAddress the target device address
	 * @param level the log level, one of:
	 * 		<ul>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_DEBUG}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_VERBOSE}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_INFO}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_APPLICATION}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_WARNING}</li>
	 * 		    <li>{@link DfuBaseService#LOG_LEVEL_ERROR}</li>
	 * 		</ul>
	 * @param message the log message
	 */
	void onLogEvent(final String deviceAddress, final int level, final String message);
}
